@@ -6,7 +6,6 @@ import aiohttp
 __all__ = (
     'BadRequest',
     'ClientNotReady',
-    'ClientResponseError',
     'Forbidden',
     'HTTPException',
     'MissingExtraRequire',
@@ -19,8 +18,9 @@ __all__ = (
 class MissingExtraRequire(Exception):
     """If a user is missing extra requirements"""
     def __init__(self, require: str):
-        message = f'Missing extra requirements. Install with `pip install toppy[{require}]`'
-        super().__init__(message)
+        # attribute so sphinx can continue
+        self.message = f'Missing extra requirements. Install with `pip install toppy[{require}]`'
+        super().__init__(self.message)
 
 
 class NoTokenSet(Exception):
@@ -30,14 +30,10 @@ class NoTokenSet(Exception):
         super().__init__(message)
 
 
-class ClientResponseError(aiohttp.ClientResponseError):
-    """An alias of :class:`aiohttp.ClientResponseError`"""
-
-
 class ClientNotReady(Exception):
     """The bot is not ready and does not have an application ID set so no ID could be found"""
     def __init__(self):
-        super().__init__(ClientNotReady.__doc__)
+        super().__init__(self.__class__.__doc__)
 
 
 class HTTPException(Exception):
@@ -61,7 +57,14 @@ class Forbidden(HTTPException):
 
 
 class RateLimited(HTTPException):
-    """Status ``429``."""
+    """
+    Status ``429``.
+    
+    Attributes
+    -----------
+    retry_after: Optional[:class:`int`]
+        The amount of seconds you can retry in.
+    """
     def __init__(self, retry_after: Optional[int] = None, resp: Optional[aiohttp.ClientResponse] = None):
         self.retry_after = retry_after
         super().__init__(resp, f'We have been ratelimited for the next {self.retry_after} seconds.')
